@@ -490,7 +490,137 @@ class ParametersLEDET:
             for k in variableGroup:
                 print(k, variableGroup[k])
 
-    def writeFileLEDET(self, nameFileLEDET, verbose: bool = False):
+    def getNumberOfCoilSections(self):
+        k = self.Inputs.M_m
+        if k.shape == (1,): return k.shape[0]
+        try:
+            if k.shape[0] != k.shape[1]: print("M_m is not square")
+        except:
+            print("M_m is not square")
+            return -1
+        return k.shape[0]
+
+    def checkM_InductanceBlock_m(self, Turns):
+        k = self.Inputs.M_InductanceBlock_m
+        if k.shape == (1,):
+            return False
+        try:
+            if k.shape[0] == k.shape[1]:
+                if k.shape[0] == Turns:
+                    return False
+        except:
+            print("M_InductanceBlock_m is not correct!")
+            return True
+        print("M_InductanceBlock_m is not correct!")
+        return True
+
+    def checkHeFraction(self, Groups):
+        k = self.Inputs.overwrite_f_externalVoids_inGroup
+        k2 = self.Inputs.overwrite_f_internalVoids_inGroup
+        if k:
+            if len(k) != len(k2):
+                print("Helium section was set but is corrupted.")
+                return False
+            if len(k) != Groups:
+                print("Helium section was set but is wrong length.")
+                return False
+        elif k2:
+            print("Helium section was set but is corrupted.")
+            return False
+        return True
+
+    def checkMonotony(self, arr, Invert=False):
+        if Invert:
+            arr = np.flip(arr)
+        b = all(x <= y for x, y in zip(arr, arr[1:]))
+        return b
+
+    def checkTimes(self):
+        t1 = min(self.Inputs.tQuench)
+        t2 = self.Inputs.t_PC_LUT[0]
+        t3 = min(self.Inputs.tStartQuench)
+        t4 = self.Options.time_vector_params[0]
+
+        if any(x < t4 for x in [t1,t2,t3]):
+            print("You're using a time, that is before the start of the simulation. Please check!")
+            return 0
+        else:
+            return 1
+
+    def consistencyCheckLEDET(self):
+        ## Consistency check of Inputs
+        ## 0 Single - 1 CoilSections - 2 Groups - 3 Half-Turns - 4 doesn't matter - 5 iContactAlongWidth - 6 iContactAlongHeight - 7 vQlength
+        ## 8 Quench Heater, 9 QuenchToFrom, 10 CLIQ,
+        slicesSameInput = [[0,1,2,49,50,51,52,55,56],
+                           [3,58,77,78],
+                           [6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33],
+                           [36,37,38,39,40,79],
+                           [4,5,34,35,53,54],
+                           [41,42],
+                           [43,44],
+                           [45,46,47,48],
+                           [63,64,65,66,67,68,69,70,71,72,73,74],
+                           [75,76],
+                           [57,59,60,61,62]]
+        lengthInputs = len(self.Inputs.__annotations__)
+        sizeInputs = np.zeros((lengthInputs,1))
+        sizeInputs[slicesSameInput[0]] = 1
+        sizeInputs[slicesSameInput[1]] = self.getNumberOfCoilSections()
+        if sizeInputs[slicesSameInput[1][0]] == -1:
+            print("M_m is corrupted. please check.")
+            return True
+        sizeInputs[slicesSameInput[2]] = len(self.Inputs.nT)
+        sizeInputs[slicesSameInput[3]] = sum(self.Inputs.nT)
+        sizeInputs[slicesSameInput[4]] = 0
+        sizeInputs[slicesSameInput[5]] = len(self.Inputs.iContactAlongWidth_From)
+        sizeInputs[slicesSameInput[6]] = len(self.Inputs.iContactAlongHeight_From)
+        sizeInputs[slicesSameInput[7]] = len(self.Inputs.iStartQuench)
+        sizeInputs[slicesSameInput[8]] = len(self.Inputs.tQH)
+        sizeInputs[slicesSameInput[9]] = len(self.Inputs.iQH_toHalfTurn_From)
+        try:
+            sizeInputs[slicesSameInput[10]] = len(self.Inputs.tCLIQ)
+        except:
+            sizeInputs[slicesSameInput[10]] = 1
+
+        if self.checkM_InductanceBlock_m(int(sum(self.Inputs.nT)/2)):
+            return 1
+
+        Count = 0
+        Break = 0
+        for k in self.Inputs.__annotations__:
+            if k== "BlankRows": continue
+            if sizeInputs[Count] == 0:
+                Count = Count + 1
+                continue
+            cC = self.getAttribute(self.Inputs, k)
+            if type(cC) == np.ndarray or type(cC) == list:
+                if not len(cC)==sizeInputs[Count]:
+                    print("The variable ",k, " does not have the correct size, should be", sizeInputs[Count]," but is ",len(cC),"! Please check.")
+                    Break = 1
+            elif type(cC) == float or type(cC) == int:
+                if not sizeInputs[Count]==1:
+                    print("The variable ", k, " does not have the correct size, should be", sizeInputs[Count]," but is ",len(cC)," Please check.")
+                    Break = 1
+            else:
+                print("Variable ", k, " has the wrong data-type set! Please check.")
+                Break = 1
+            Count = Count + 1
+        if not self.checkHeFraction(len(self.Inputs.nT)): Break = 1
+        if not self.checkMonotony(self.Inputs.t_PC_LUT):
+            print("t_PC_LUT is not monotonic")
+            Break = 1
+        # if not self.checkMonotony(self.Inputs.fL_L, Invert=True):
+        #     print("fL_L is not monotonic")
+        #     Break = 1
+        if not self.checkMonotony(self.Inputs.fL_I):
+            print("fL_I is not monotonic")
+            Break = 1
+        if not self.checkTimes():
+            Break = 1
+
+        return Break
+
+    def writeFileLEDET(self, nameFileLEDET, verbose: bool = False, SkipConsistencyCheck: bool = False):
         '''
             **Writes LEDET input file **
 
@@ -503,6 +633,12 @@ class ParametersLEDET:
 
             :return: None
         '''
+        if not SkipConsistencyCheck:
+            if self.consistencyCheckLEDET():
+                print("Variables are not consistent! Writing aborted.")
+                return
+            else:
+                print("Preliminary consistency check was successful!")
 
         workbook = xlsxwriter.Workbook(nameFileLEDET)
 
