@@ -383,7 +383,7 @@ class ParametersCOSIM:
         for n in range(0, N_LEDET):
             if DistinctMagnets != 1:
                 DM = n+1
-                M_add = "M"+str(DM)
+                M_add = "M"+str(DM)+'_'
             else:
                 DM = 1
                 M_add = ''
